pytilities.overloading.compositeparameter — Pytilities 1.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »
- pytilities.overloading »

# pytilities.overloading.compositeparameter

`pytilities.overloading.compositeparameter.` `CompositeParam`

  alias of `CompositeParameter`

class `pytilities.overloading.compositeparameter.` `CompositeParameter`(name, params, matcher=(<class 'tuple'>, <class 'list'>, <class 'dict'>), *args, **kwargs)

  Parameter that consists of more parameters.

  This parameter matches lists, tuples and dicts, of which all elements match the list of child parameters.

  When this parameter is written to a dict, its child parameters are expanded. E.g. for a composite parameter with childs ‘x’ and ‘y’, a read value of (1, 3) and a dict d of {}; after writing to d, d will equal {x:1, y:3}, and not {{x:1, y:3}}.

  `write`(kwargs)

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »
- pytilities.overloading »